@@ -1,12 +1,13 @@
 use crate::{
-    buffers::Indicator,
     handles::{CData, CDataMut, HasDataType},
     DataType,
 };
 
+use super::{ColumnBuffer, ColumnProjections, Indicator};
+
 use log::debug;
 use odbc_sys::{CDataType, NULL_DATA};
-use std::{cmp::min, convert::TryInto, ffi::c_void, mem::size_of};
+use std::{cmp::min, ffi::c_void, mem::size_of};
 use widestring::U16Str;
 
 /// A column buffer for character data. The actual encoding used may depend on your system locale.
@@ -110,7 +111,7 @@ impl<C> TextColumn<C> {
     ///
     /// * `new_max_str_len`: New maximum string length without terminating zero.
     /// * `num_rows`: Number of valid rows currently stored in this buffer.
-    pub fn rebind(&mut self, new_max_str_len: usize, num_rows: usize)
+    pub fn resize_max_str(&mut self, new_max_str_len: usize, num_rows: usize)
     where
         C: Default + Copy,
     {
@@ -184,7 +185,7 @@ impl<C> TextColumn<C> {
         if let Some(text) = text {
             if text.len() > self.max_str_len {
                 let new_max_str_len = (text.len() as f64 * 1.2) as usize;
-                self.rebind(new_max_str_len, index)
+                self.resize_max_str(new_max_str_len, index)
             }
 
             let offset = index * (self.max_str_len + 1);
@@ -309,6 +310,34 @@ impl WCharColumn {
     }
 }
 
+unsafe impl<'a, C: 'static> ColumnProjections<'a> for TextColumn<C> {
+    type View = TextColumnIt<'a, C>;
+
+    type ViewMut = TextColumnWriter<'a, C>;
+}
+
+unsafe impl<C: 'static> ColumnBuffer for TextColumn<C>
+where
+    TextColumn<C>: CDataMut + HasDataType,
+{
+    unsafe fn view(&self, valid_rows: usize) -> TextColumnIt<'_, C> {
+        self.iter(valid_rows)
+    }
+
+    unsafe fn view_mut(&mut self, valid_rows: usize) -> TextColumnWriter<'_, C> {
+        self.writer_n(valid_rows)
+    }
+
+    fn fill_default(&mut self, from: usize, to: usize) {
+        self.fill_null(from, to)
+    }
+
+    /// Maximum number of text strings this column may hold.
+    fn capacity(&self) -> usize {
+        self.indicators.len()
+    }
+}
+
 /// Iterator over a text column. See [`TextColumn::iter`]
 #[derive(Debug)]
 pub struct TextColumnIt<'c, C> {
@@ -419,7 +448,7 @@ where
     ///   contained values after `num_rows` their indicator values remain, but their values will be
     ///   all zeroes.
     pub fn rebind(&mut self, new_max_str_len: usize, num_rows: usize) {
-        self.column.rebind(new_max_str_len, num_rows)
+        self.column.resize_max_str(new_max_str_len, num_rows)
     }
 
     /// Change a single value in the column at the specified index.
@@ -442,7 +471,9 @@ where
     /// # Example
     ///
     /// ```
-    /// # use odbc_api::buffers::{ColumnarRowSet, BufferDescription, BufferKind, AnyColumnViewMut};
+    /// # use odbc_api::buffers::{
+    /// #   BufferDescription, BufferKind, AnyColumnViewMut, buffer_from_description
+    /// # };
     /// # use std::iter;
     /// #
     /// let desc = BufferDescription {
@@ -461,7 +492,7 @@ where
     ///     Some(&b"Hello, World!"[..]),
     /// ];
     ///
-    /// let mut buffer = ColumnarRowSet::new(input.len(), iter::once(desc));
+    /// let mut buffer = buffer_from_description(input.len(), iter::once(desc));
     ///
     /// buffer.set_num_rows(input.len());
     /// if let AnyColumnViewMut::Text(mut writer) = buffer.column_mut(0) {
