@@ -2,15 +2,15 @@ use std::{cmp::max, collections::HashMap, ptr::null_mut, sync::Mutex};
 
 use crate::{
     handles::{self, log_diagnostics, OutputStringBuffer, SqlResult, State},
-    Connection, Error,
+    Connection, DriverCompleteOption, Error,
 };
 use log::debug;
 use odbc_sys::{AttrCpMatch, AttrOdbcVersion, FetchOrientation, HWnd};
 use widestring::{U16CStr, U16Str, U16String};
 
-// Currently only windows driver manager supports prompt.
 #[cfg(target_os = "windows")]
-use raw_window_handle::{HasRawWindowHandle, RawWindowHandle};
+// Currently only windows driver manager supports prompt.
+use winit::{event_loop::EventLoop, platform::windows::WindowExtWindows, window::WindowBuilder};
 
 /// An ODBC 3.8 environment.
 ///
@@ -299,7 +299,10 @@ impl Environment {
     ///   * Maria DB crashes with STATUS_TACK_BUFFER_OVERRUN
     ///   * SQLite does not change the output buffer at all and does not indicate truncation.
     /// * `driver_completion`: Specifies how and if the driver manager uses a prompt to complete
-    ///   the provided connection string.
+    ///   the provided connection string. For arguments other than
+    ///   [`crate::DriverCompleteOption::NoPrompt`] this method is going to create a message only
+    ///   parent window for you on windows. On other platform this method is going to panic. In case
+    ///   you want to provide your own parent window please use [`Self::driver_connect_with_hwnd`].
     ///
     /// # Examples
     ///
@@ -308,9 +311,6 @@ impl Environment {
     /// windows.
     ///
     /// ```no_run
-    /// # #[cfg(target_os = "widows")]
-    /// # fn f(parent_window: impl raw_window_handle::HasRawWindowHandle)
-    /// #   -> Result<(), odbc_api::Error> {
     /// use odbc_api::{Environment, handles::OutputStringBuffer, DriverCompleteOption};
     ///
     /// let env = Environment::new()?;
@@ -319,7 +319,7 @@ impl Environment {
     /// let connection = env.driver_connect(
     ///     "",
     ///     Some(&mut output_buffer),
-    ///     DriverCompleteOption::Prompt(&parent_window),
+    ///     DriverCompleteOption::Prompt,
     /// )?;
     ///
     /// // Check that the output buffer has been large enough to hold the entire connection string.
@@ -327,7 +327,7 @@ impl Environment {
     ///
     /// // Now `connection_string` will contain the data source selected by the user.
     /// let connection_string = output_buffer.to_utf8();
-    /// # Ok(()) }
+    /// # Ok::<_,odbc_api::Error>(())
     /// ```
     ///
     /// In the following examples we specify a DSN that requires login credentials, but the DSN does
@@ -339,7 +339,6 @@ impl Environment {
     /// # use odbc_api::DriverCompleteOption;
     /// # #[cfg(target_os = "windows")]
     /// # fn f(
-    /// #    parent_window: impl raw_window_handle::HasRawWindowHandle,
     /// #    mut output_buffer: odbc_api::handles::OutputStringBuffer,
     /// #    env: odbc_api::Environment,
     /// # ) -> Result<(), odbc_api::Error> {
@@ -347,7 +346,7 @@ impl Environment {
     /// let connection = env.driver_connect(
     ///     &without_uid_or_pwd,
     ///     Some(&mut output_buffer),
-    ///     DriverCompleteOption::Complete(&parent_window),
+    ///     DriverCompleteOption::Complete,
     /// )?;
     /// let connection_string = output_buffer.to_utf8();
     ///
@@ -382,21 +381,69 @@ impl Environment {
         &self,
         connection_string: &str,
         completed_connection_string: Option<&mut OutputStringBuffer>,
-        driver_completion: DriverCompleteOption<'_>,
+        driver_completion: DriverCompleteOption,
+    ) -> Result<Connection<'_>, Error> {
+        #[cfg(target_os = "windows")]
+        let parent_window = match driver_completion {
+            DriverCompleteOption::NoPrompt => None,
+            _ => {
+                if !cfg!(target_os = "windows") {
+                    panic!("Prompt is not supported on non windows platforms. Use `NoPrompt`.")
+                }
+                // We need a parent window, let's provide a message only window.
+                Some(
+                    WindowBuilder::new()
+                        .with_visible(false)
+                        .build(&EventLoop::new())
+                        .unwrap(),
+                )
+            }
+        };
+        #[cfg(target_os = "windows")]
+        let hwnd = parent_window
+            .as_ref()
+            .map(|window| window.hwnd())
+            .unwrap_or_else(null_mut);
+        #[cfg(not(target_os = "windows"))]
+        let hwnd = null_mut();
+        unsafe {
+            self.driver_connect_with_hwnd(
+                connection_string,
+                completed_connection_string,
+                driver_completion,
+                hwnd,
+            )
+        }
+    }
+
+    /// Allows to call driver connect with a user supplied HWnd. Same as [`Self::driver_connect`],
+    /// but with the possibility to provide your own parent window handle in case you want to show
+    /// a prompt to the user.
+    ///
+    /// # Safety
+    ///
+    /// `parent_window` must be a valid window handle, to a window type supported by the ODBC driver
+    /// manager. On windows this is a plain window handle, which is of course understood by the
+    /// windows built in ODBC driver manager. Other working combinations are unknown to the author.
+    pub unsafe fn driver_connect_with_hwnd(
+        &self,
+        connection_string: &str,
+        completed_connection_string: Option<&mut OutputStringBuffer>,
+        driver_completion: DriverCompleteOption,
+        parent_window: HWnd,
     ) -> Result<Connection<'_>, Error> {
         let mut connection = self.allocate_connection()?;
         let connection_string = U16String::from_str(connection_string);
 
-        unsafe {
-            connection.driver_connect(
+        connection
+            .driver_connect(
                 &connection_string,
-                driver_completion.parent_window(),
+                parent_window,
                 completed_connection_string,
                 driver_completion.as_sys(),
             )
-        }
-        .map(|res| res.into_result(&connection))
-        .unwrap_or(Err(Error::AbortedConnectionStringCompletion))?;
+            .map(|res| res.into_result(&connection))
+            .unwrap_or(Err(Error::AbortedConnectionStringCompletion))?;
         Ok(Connection::new(connection))
     }
 
@@ -600,76 +647,6 @@ impl Environment {
     }
 }
 
-#[cfg(not(target_os = "windows"))]
-#[doc(hidden)]
-pub struct NonExhaustive<'a>(std::marker::PhantomData<&'a i32>);
-
-/// Specifies how the driver and driver manager complete the incoming connection string. See
-/// [`Environment::driver_connect`].
-pub enum DriverCompleteOption<'a> {
-    /// Do not show a prompt to the user. This implies that the connection string, must already
-    /// provide all information needed to Connect to the data source, otherwise the operation fails.
-    /// This is the only variant on non windows platforms
-    NoPrompt,
-    /// Always show a prompt to the user.
-    #[cfg(target_os = "windows")]
-    Prompt(&'a dyn HasRawWindowHandle),
-    /// Only show a prompt to the user if the information in the connection string is not sufficient
-    /// to connect to the data source.
-    #[cfg(target_os = "windows")]
-    Complete(&'a dyn HasRawWindowHandle),
-    /// Like complete, but the user may not change any information already provided within the
-    /// connection string.
-    #[cfg(target_os = "windows")]
-    CompleteRequired(&'a dyn HasRawWindowHandle),
-    // Solves two problems for us.
-    //
-    // 1. We do not need a breaking change if we decide to add prompt support for non windows
-    //    platforms
-    // 2. Provides us with a place for the 'a lifetime so the borrow checker won't complain.
-    #[cfg(not(target_os = "windows"))]
-    #[doc(hidden)]
-    __NonExhaustive(NonExhaustive<'a>),
-}
-
-impl<'a> DriverCompleteOption<'a> {
-    #[cfg(target_os = "windows")]
-    pub fn parent_window(&self) -> HWnd {
-        let has_raw_window_handle = match self {
-            DriverCompleteOption::NoPrompt => return null_mut(),
-            DriverCompleteOption::Prompt(hrwh)
-            | DriverCompleteOption::Complete(hrwh)
-            | DriverCompleteOption::CompleteRequired(hrwh) => hrwh,
-        };
-        match has_raw_window_handle.raw_window_handle() {
-            RawWindowHandle::Windows(handle) => handle.hwnd,
-            _ => null_mut(),
-        }
-    }
-
-    #[cfg(not(target_os = "windows"))]
-    pub fn parent_window(&self) -> HWnd {
-        null_mut()
-    }
-
-    #[cfg(target_os = "windows")]
-    pub fn as_sys(&self) -> odbc_sys::DriverConnectOption {
-        match self {
-            DriverCompleteOption::NoPrompt => odbc_sys::DriverConnectOption::NoPrompt,
-            DriverCompleteOption::Prompt(_) => odbc_sys::DriverConnectOption::Prompt,
-            DriverCompleteOption::Complete(_) => odbc_sys::DriverConnectOption::Complete,
-            DriverCompleteOption::CompleteRequired(_) => {
-                odbc_sys::DriverConnectOption::CompleteRequired
-            }
-        }
-    }
-
-    #[cfg(not(target_os = "windows"))]
-    pub fn as_sys(&self) -> odbc_sys::DriverConnectOption {
-        odbc_sys::DriverConnectOption::NoPrompt
-    }
-}
-
 /// Struct holding information available on a driver. Can be obtained via [`Environment::drivers`].
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct DriverInfo {
