@@ -325,7 +325,7 @@ This crate also provides two implementation of the [`crate::RowSetBuffer`] trait
 used in safe code:
 
 * [`crate::buffers::TextRowSet`]
-* [`crate::buffers::ColumnarRowSet`]
+* [`crate::buffers::ColumnarBuffer`]
 
 ### Fetching results row by row without binding buffers upfront.
 
@@ -354,14 +354,14 @@ fn get_large_text(name: &str, conn: &mut Connection<'_>) -> Result<Option<String
 }
 ```
 
-### Fetching results column wise with `ColumnarRowSet`.
+### Fetching results column wise with `ColumnarBuffer`.
 
 Consider querying a table with two columns `year` and `name`.
 
 ```no_run
 use odbc_api::{
     Environment, Cursor,
-    buffers::{AnyColumnView, ColumnarRowSet, BufferDescription, BufferKind, Item},
+    buffers::{AnyColumnView, BufferDescription, BufferKind, Item, buffer_from_description},
 };
 
 let env = Environment::new()?;
@@ -379,7 +379,12 @@ let buffer_description = [
         nullable: false,
     }
 ];
-let mut buffer = ColumnarRowSet::new(batch_size, buffer_description.iter().copied());
+
+/// Creates a columnar buffer fitting the buffer description with the capacity of `batch_size`.
+let mut buffer = buffer_from_description(
+    batch_size,
+    buffer_description.iter().copied()
+);
 
 let mut conn = env.connect("YourDatabase", "SA", "<YourStrong@Passw0rd>")?;
 if let Some(cursor) = conn.execute("SELECT year, name FROM Birthdays;", ())? {
@@ -416,11 +421,13 @@ have an easier time with the borrow checker.
 ```no_run
 use odbc_api::{
     Connection, RowSetCursor, Error, Cursor, Nullability, ResultSetMetadata,
-    buffers::{ColumnarRowSet, BufferDescription, BufferKind}
+    buffers::{
+        AnyColumnBuffer, BufferDescription, BufferKind, buffer_from_description, ColumnarBuffer
+    }
 };
 
 fn get_birthdays<'a>(conn: &'a mut Connection)
-    -> Result<RowSetCursor<impl Cursor + 'a, ColumnarRowSet>, Error>
+    -> Result<RowSetCursor<impl Cursor + 'a, ColumnarBuffer<AnyColumnBuffer>>, Error>
 {
     let cursor = conn.execute("SELECT year, name FROM Birthdays;", ())?.unwrap();
     let mut column_description = Default::default();
@@ -435,7 +442,7 @@ fn get_birthdays<'a>(conn: &'a mut Connection)
     }).collect::<Result<_, Error>>()?;
 
     // Row set size of 5000 rows.
-    let buffer = ColumnarRowSet::new(5000, buffer_description.into_iter());
+    let buffer = buffer_from_description(5000, buffer_description.into_iter());
     // Bind buffer and take ownership over it.
     cursor.bind_buffer(buffer)
 }
@@ -464,13 +471,13 @@ fn insert_birth_year(conn: &Connection, name: &str, year: i16) -> Result<(), Err
 
 Inserting values row by row can introduce a lot of overhead. ODBC allows you to perform either
 row or column wise bulk inserts. Especially in pipelines for data science you may already have
-buffers in a columnar layout at hand. [`crate::buffers::ColumnarRowSet`] can be used for bulk
+buffers in a columnar layout at hand. [`crate::buffers::ColumnarBuffer`] can be used for bulk
 inserts.
 
 ```no_run
 use odbc_api::{
     Connection, Error, IntoParameter,
-    buffers::{ColumnarRowSet, BufferDescription, BufferKind, AnyColumnViewMut, Item}
+    buffers::{BufferDescription, BufferKind, AnyColumnViewMut, Item, buffer_from_description}
 };
 
 fn insert_birth_years(conn: &Connection, names: &[&str], years: &[i16]) -> Result<(), Error> {
@@ -489,7 +496,7 @@ fn insert_birth_years(conn: &Connection, names: &[&str], years: &[i16]) -> Resul
             nullable: false,
         },
     ];
-    let mut buffer = ColumnarRowSet::new(
+    let mut buffer = buffer_from_description(
         names.len(),
         buffer_description.iter().copied()
     );
