@@ -16,6 +16,7 @@ mod into_parameter;
 mod nullable;
 mod parameter_collection;
 mod preallocated;
+mod prebound;
 mod prepared;
 mod result_set_metadata;
 mod statement_connection;
@@ -35,9 +36,10 @@ pub use self::{
     handles::{ColumnDescription, DataType, Nullability},
     into_parameter::IntoParameter,
     nullable::Nullable,
-    parameter::{InputParameter, Out, Output, Parameter},
-    parameter_collection::ParameterCollection,
+    parameter::{InOut, Out, OutputParameter, ParameterRef},
+    parameter_collection::ParameterRefCollection,
     preallocated::Preallocated,
+    prebound::Prebound,
     prepared::Prepared,
     result_set_metadata::ResultSetMetadata,
     statement_connection::StatementConnection,
